/* Create by: Ricardo Concepcion
website: https://www.rjconcepcion.com

*/

// Libraries
#include <ESP8266WiFi.h>
#include <NTPClient.h>
#include <WiFiUdp.h>
#include "config.h"

const char *ssid     = "YOUR_WIFI_NAME"; 
const char *password = "YOUR_WIFI_PASSWORD"; 

// Define NTP Client
WiFiUDP ntp;
NTPClient timeClient(ntp, "pool.ntp.org");

const int trigger = 4;  // D2 Pin connect to sensor trigger pin
const int echo = 5;     // D1 pin connected to sensor echo pin
const int max_dist = 200; // max distance in cm

// Variables
int hour;
int minutes;
int dist = 0; 
float tiempo = 0;

AdafruitIO_Feed *tiempo_feed = io.feed("tiempo_feed");

void setup() {

  // Initialize Serial Monitor
  Serial.begin(9600);

   // Connect to Wi-Fi
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }

  pinMode(trigger, OUTPUT);
  pinMode(echo, INPUT);

  // connect to io.adafruit.com
  Serial.print("Connecting to Adafruit IO");
  io.connect();

  // wait for a connection
  while(io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());

  // Initialize NTPClient
  timeClient.begin();

  // Offset time is the different between 0 GMT and your time zone. In my case is -4 GMT. It is equal to -14400.
  timeClient.setTimeOffset(-14400); 

}

void loop() {
  // 

  io.run();
  timeClient.update();

  // Get hour
  hour = timeClient.getHours();
  Serial.print("Hour: ");
  Serial.println(hour);

  // Get minutes
  minutes = timeClient.getMinutes();
  Serial.print("Minutes: ");
  Serial.println(minutes);

  // get the distance between the sensor and the object
  dist = ping(trigger, echo); 
  Serial.print(dist);     
  Serial.println("cm");

  // if the distance is lower than 100 cm then count the time
  if(dist < 100) {
    while (dist < 100) {
      delay(60000); // wait for one minute
      tiempo += 1;  // increase the counter
      dist = ping(trigger, echo);
      Serial.println(dist);

      timeClient.update();
      hour = timeClient.getHours();
      minutes = timeClient.getMinutes();
      io.run();

      // if the time is 00:00 then send the data to Adafruit IO
      if((hour == 0 && minutes == 0)){
        Serial.println(tiempo);
        Serial.println("Se envia a Adafruit");
        tiempo_feed->save(tiempo);
        tiempo = 0; // restart the counter
      }
      
    }
  }

  // if the time is 00:00 then send the data to Adafruit IO
  if(hour == 0 && minutes == 0){
    tiempo_feed->save(tiempo);
    tiempo = 0;
  }

  Serial.println(tiempo);
  delay(60000); 
  
}

int ping(int TriggerPin, int EchoPin) {
   long duration, distanceCm;
   
   digitalWrite(TriggerPin, LOW);  // 4us LOW pulse
   delayMicroseconds(4);
   digitalWrite(TriggerPin, HIGH);  // 10us HIGH pulse
   delayMicroseconds(10);
   digitalWrite(TriggerPin, LOW);
   
   duration = pulseIn(EchoPin, HIGH);  // mesure time between pulses, result in microseconds
   
   distanceCm = duration * 10 / 292/ 2;   // Change distance to centimeters
   return distanceCm;
}
